Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(686)

Unified Diff: components/crash/content/app/breakpad_win.cc

Issue 2769023004: Cloud Print process type: service -> cloud-print-service (Closed)
Patch Set: . Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/service/service_main.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/crash/content/app/breakpad_win.cc
diff --git a/components/crash/content/app/breakpad_win.cc b/components/crash/content/app/breakpad_win.cc
index c80c02303db6fca918729117233507dc48eabba9..c236230959e7ea15556cba2b78b1c8088ef0b9fb 100644
--- a/components/crash/content/app/breakpad_win.cc
+++ b/components/crash/content/app/breakpad_win.cc
@@ -290,10 +290,10 @@ long WINAPI ChromeExceptionFilter(EXCEPTION_POINTERS* info) {
return EXCEPTION_EXECUTE_HANDLER;
}
-// Exception filter for the service process used when breakpad is not enabled.
-// We just display the "Do you want to restart" message and then die
-// (without calling the previous filter).
-long WINAPI ServiceExceptionFilter(EXCEPTION_POINTERS* info) {
+// Exception filter for the Cloud Print service process used when breakpad is
+// not enabled. We just display the "Do you want to restart" message and then
+// die (without calling the previous filter).
+long WINAPI CloudPrintServiceExceptionFilter(EXCEPTION_POINTERS* info) {
DumpDoneCallback(NULL, NULL, NULL, info, NULL, false);
return EXCEPTION_EXECUTE_HANDLER;
}
@@ -581,9 +581,9 @@ void InitCrashReporter(const std::string& process_type_switch) {
if (process_type == L"browser") {
callback = &DumpDoneCallback;
default_filter = &ChromeExceptionFilter;
- } else if (process_type == L"service") {
+ } else if (process_type == L"cloud-print-service") {
callback = &DumpDoneCallback;
- default_filter = &ServiceExceptionFilter;
+ default_filter = &CloudPrintServiceExceptionFilter;
}
if (GetCrashReporterClient()->ShouldCreatePipeName(process_type))
« no previous file with comments | « chrome/service/service_main.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698